========
audtorch
========

|tests| |coverage| |docs| |license|

Deep learning with PyTorch_ and audio.

**Documentation:** https://audtorch.readthedocs.io

If you are interested in PyTorch_ and audio you should also check out the
efforts to integrate more audio directly into PyTorch_:

* `pytorch/audio`_
* `keunwoochoi/torchaudio-contrib`_

.. _PyTorch: https://pytorch.org
.. _pytorch/audio: https://github.com/pytorch/audio
.. _keunwoochoi/torchaudio-contrib:
    https://github.com/keunwoochoi/torchaudio-contrib

.. |tests| image:: https://github.com/audeering/audtorch/workflows/Test/badge.svg
    :target: https://github.com/audeering/audtorch/actions?query=workflow%3ATest
    :alt: Test status
.. |coverage| image:: https://codecov.io/gh/audeering/audtorch/branch/master/graph/badge.svg?token=PUA9P2UJW1
    :target: https://codecov.io/gh/audeering/audtorch/
    :alt: code coverage
.. |docs| image:: https://readthedocs.org/projects/audtorch/badge/
    :target: https://audtorch.readthedocs.io/
    :alt: audtorch's documentation on Read the Docs
.. |license| image:: https://img.shields.io/badge/license-MIT-green.svg
    :target: https://github.com/audeering/audtorch/blob/master/LICENSE
    :alt: audtorch's MIT license
